# paperchill - a papermill with chat functionality

`paperchill` is a proof of concept that lets you upload a paper in PDF format, gives you a summary of the paper, and
answers questions about the paper.

## Installation
```shell
$ pip install paperchill
```